@@ -1209,7 +1209,7 @@ void DiffTextWindow::print(RLPainter& p, const QRect&, int firstLine, const Line
 void DiffTextWindowData::draw(RLPainter& p, const QRect& invalidRect, const int beginLine, const LineRef& endLine)
 {
     if(m_pLineData == nullptr || m_pLineData->empty()) return;
-    m_lineNumberWidth = m_pOptions->m_bShowLineNumbers ? (int)log10((double)std::max(m_size, 1)) + 1 : 0;
+    m_lineNumberWidth = m_pOptions->m_bShowLineNumbers ? m_pDiffTextWindow->getLineNumberWidth() : 0;
 
     if(m_winIdx == e_SrcSelector::A)
     {
@@ -1620,7 +1620,7 @@ void DiffTextWindow::recalcWordWrap(bool bWordWrap, QtSizeType wrapLineVectorSiz
 
     if(bWordWrap)
     {
-        d->m_lineNumberWidth = d->getOptions()->m_bShowLineNumbers ? (int)log10((double)std::max(d->m_size, 1)) + 1 : 0;
+        d->m_lineNumberWidth = d->getOptions()->m_bShowLineNumbers ? getLineNumberWidth() : 0;
 
         d->m_diff3WrapLineVector.resize(wrapLineVectorSize);
 
@@ -1679,7 +1679,7 @@ void DiffTextWindow::recalcWordWrapHelper(QtSizeType wrapLineVectorSize, int vis
         QtSizeType cacheListIdx2 = 0;
         QTextLayout textLayout(QString(), font(), this);
 
-        for(i = firstD3LineIdx; i < endIdx; ++i)
+        for(i = firstD3LineIdx; wrapLineIdx < d->m_diff3WrapLineVector.size() && i < endIdx; ++i)
         {
             if(g_pProgressDialog->wasCancelled())
                 return;
@@ -1707,7 +1707,7 @@ void DiffTextWindow::recalcWordWrapHelper(QtSizeType wrapLineVectorSize, int vis
                 QtSizeType curCount = d->m_wrapLineCacheList[cacheListIdx2].count() - 1;
                 LineCount l = 0;
 
-                while((cacheListIdx2 < clc || (cacheListIdx2 == clc && cacheIdx < cllc)) && pWrapLineCache->d3LineIdx() <= i)
+                while(wrapLineIdx + l < d->m_diff3WrapLineVector.size() && (cacheListIdx2 < clc || (cacheListIdx2 == clc && cacheIdx < cllc)) && pWrapLineCache->d3LineIdx() <= i)
                 {
                     if(pWrapLineCache->d3LineIdx() == i)
                     {
@@ -1744,7 +1744,7 @@ void DiffTextWindow::recalcWordWrapHelper(QtSizeType wrapLineVectorSize, int vis
             if(wrapLineVectorSize > 0)
             {
                 int j;
-                for(j = 0; j < d3l.linesNeededForDisplay(); ++j, ++wrapLineIdx)
+                for(j = 0; wrapLineIdx < d->m_diff3WrapLineVector.size() && j < d3l.linesNeededForDisplay(); ++j, ++wrapLineIdx)
                 {
                     Diff3WrapLine& d3wl = d->m_diff3WrapLineVector[wrapLineIdx];
                     d3wl.diff3LineIndex = i;
