@@ -348,6 +348,7 @@ void FileAccess::loadData()
     if(isLocal() && m_bSymLink)
     {
         m_linkTarget = m_fileInfo.symLinkTarget();
+
 #ifndef Q_OS_WIN
         // Unfortunately Qt5 symLinkTarget/readLink always returns an absolute path, even if the link is relative
         char* s = (char*)malloc(PATH_MAX + 1);
@@ -359,6 +360,14 @@ void FileAccess::loadData()
         }
         free(s);
 #endif
+
+        m_bBrokenLink = !QFileInfo::exists(m_linkTarget);
+        //We want to know if the link itself exists
+        if(!m_bExists)
+            m_bExists = true;
+
+        if(!m_modificationTime.isValid())
+            m_modificationTime = QDateTime::fromMSecsSinceEpoch(0);
     }
 
     realFile = QSharedPointer<QFile>::create(absoluteFilePath());
@@ -539,10 +548,11 @@ void FileAccess::setFromUdsEntry(const KIO::UDSEntry& e, FileAccess* parent)
 
     if(isLocal())
     {
-        m_bExists = m_fileInfo.exists();
+        m_bBrokenLink = !m_fileInfo.exists() && m_fileInfo.isSymLink();
+        m_bExists = m_fileInfo.exists() || m_bBrokenLink;
 
         //insure modification time is initialized if it wasn't already.
-        if(m_modificationTime == QDateTime::fromMSecsSinceEpoch(0))
+        if(!m_bBrokenLink && m_modificationTime == QDateTime::fromMSecsSinceEpoch(0))
             m_modificationTime = m_fileInfo.lastModified();
     }
 
@@ -630,8 +640,9 @@ bool FileAccess::exists() const
 {
     if(!isLocal())
         return m_bExists;
-    else//Thank you git for being different.
-        return m_fileInfo.exists() && absoluteFilePath() != "/dev/null";
+    else
+        return (m_fileInfo.exists() || isSymLink()) && // QFileInfo.exists returns false for broken links,
+               absoluteFilePath() != "/dev/null";      // git uses /dev/null as a placeholder meaning does not exist
 }
 
 qint64 FileAccess::size() const
