@@ -410,6 +410,94 @@ void KDiff3App::slotFocusChanged(QWidget* old, QWidget* now)
     Q_EMIT updateAvailabilities();
 }
 
+// Do file comparision.
+bool KDiff3App::doFileCompare()
+{
+    bool bSuccess = true;
+    improveFilenames();
+    m_pDirectoryMergeDock->hide();
+    m_pDirectoryMergeInfoDock->hide();
+
+    mainInit(m_totalDiffStatus);
+    if(m_bAutoMode)
+    {
+        QSharedPointer<SourceData> pSD = nullptr;
+        if(m_sd3->isEmpty())
+        {
+            if(m_totalDiffStatus->isBinaryEqualAB())
+            {
+                pSD = m_sd1;
+            }
+        }
+        else
+        {
+            if(m_totalDiffStatus->isBinaryEqualBC() || m_totalDiffStatus->isBinaryEqualAB())
+            {
+                //if B==C (assume A is old), if A==B then C has changed
+                pSD = m_sd3;
+            }
+            else if(m_totalDiffStatus->isBinaryEqualAC())
+            {
+                pSD = m_sd2; // assuming B has changed
+            }
+        }
+
+        if(pSD != nullptr)
+        {
+            // Save this file directly, not via the merge result window.
+            FileAccess fa(m_outputFilename);
+            if(m_pOptions->m_bDmCreateBakFiles && fa.exists())
+            {
+                fa.createBackup(".orig");
+            }
+
+            bSuccess = pSD->saveNormalDataAs(m_outputFilename);
+            if(!bSuccess)
+                KMessageBox::error(this, i18n("Saving failed."));
+        }
+        else if(m_pMergeResultWindow->getNumberOfUnsolvedConflicts() == 0)
+        {
+            bSuccess = m_pMergeResultWindow->saveDocument(m_pMergeResultWindowTitle->getFileName(), m_pMergeResultWindowTitle->getEncoding(), m_pMergeResultWindowTitle->getLineEndStyle());
+        }
+        if(bSuccess)
+        {
+            QMetaObject::invokeMethod(qApp, &QApplication::quit, Qt::QueuedConnection);
+        }
+    }
+    return bSuccess;
+}
+
+// Restore and show mainWindow.
+void KDiff3App::showMainWindow()
+{
+    if(!m_pKDiff3Shell->isVisible() && !restoreWindow(KSharedConfig::openConfig()))
+    {
+        /*
+            Set default state/geometry from config file.
+            This will no longer be updated but serves as a fallback.
+            Qt's restoreState/saveState can handle multiple screens this won't.
+        */
+        if(m_pOptions->isFullScreen())
+            m_pKDiff3Shell->showFullScreen();
+        else if(m_pOptions->isMaximised())
+            m_pKDiff3Shell->showMaximized();
+
+        QSize size = m_pOptions->getGeometry();
+        QPoint pos = m_pOptions->getPosition();
+
+        if(!size.isEmpty())
+        {
+            m_pKDiff3Shell->resize(size);
+
+            QRect visibleRect = QRect(pos, size) & QApplication::desktop()->rect();
+            if(visibleRect.width() > 100 && visibleRect.height() > 100)
+                m_pKDiff3Shell->move(pos);
+        }
+    }
+
+    m_pKDiff3Shell->show();
+}
+
 void KDiff3App::completeInit(const QString& fn1, const QString& fn2, const QString& fn3)
 {
     if(!fn1.isEmpty()) {
@@ -432,90 +520,25 @@ void KDiff3App::completeInit(const QString& fn1, const QString& fn2, const QStri
         m_bAutoMode = false;
     }
 
-    if(!isPart())
-    {
-        if(!m_pKDiff3Shell->isVisible() && !restoreWindow(KSharedConfig::openConfig()))
-        {
-            /*
-                Set default state/geometry from config file.
-                This will no longer be updated but serves as a fallback.
-                Qt's restoreState/saveState can handle multiple screens this won't.
-            */
-            if(m_pOptions->isFullScreen())
-                m_pKDiff3Shell->showFullScreen();
-            else if(m_pOptions->isMaximised())
-                m_pKDiff3Shell->showMaximized();
+    if(!m_bAutoMode && !isPart())
+        showMainWindow();
 
-            QSize size = m_pOptions->getGeometry();
-            QPoint pos = m_pOptions->getPosition();
-
-            if(!size.isEmpty())
-            {
-                m_pKDiff3Shell->resize(size);
-
-                QRect visibleRect = QRect(pos, size) & QApplication::desktop()->rect();
-                if(visibleRect.width() > 100 && visibleRect.height() > 100)
-                    m_pKDiff3Shell->move(pos);
-            }
-        }
-
-        m_pKDiff3Shell->show();
-    }
     g_pProgressDialog->setStayHidden(false);
 
     bool bSuccess = true;
     if(m_bDirCompare)
         bSuccess = doDirectoryCompare(false);
     else
+        bSuccess = doFileCompare();
+
+    if(bSuccess)
     {
-        improveFilenames();
-        m_pDirectoryMergeDock->hide();
-        m_pDirectoryMergeInfoDock->hide();
-
-        mainInit(m_totalDiffStatus);
         if(m_bAutoMode)
-        {
-            QSharedPointer<SourceData> pSD = nullptr;
-            if(m_sd3->isEmpty()) {
-                if(m_totalDiffStatus->isBinaryEqualAB()) {
-                    pSD = m_sd1;
-                }
-            }
-            else
-            {
-                if(m_totalDiffStatus->isBinaryEqualBC() || m_totalDiffStatus->isBinaryEqualAB())
-                {
-                    //if B==C (assume A is old), if A==B then C has changed
-                    pSD = m_sd3;
-                }
-                else if(m_totalDiffStatus->isBinaryEqualAC())
-                {
-                    pSD = m_sd2; // assuming B has changed
-                }
-            }
+            return;
 
-            if(pSD != nullptr)
-            {
-                // Save this file directly, not via the merge result window.
-                FileAccess fa(m_outputFilename);
-                if(m_pOptions->m_bDmCreateBakFiles && fa.exists())
-                {
-                    fa.createBackup(".orig");
-                }
-
-                bSuccess = pSD->saveNormalDataAs(m_outputFilename);
-                if(bSuccess)
-                    ::exit(0);
-                else
-                    KMessageBox::error(this, i18n("Saving failed."));
-            }
-            else if(m_pMergeResultWindow->getNumberOfUnsolvedConflicts() == 0)
-            {
-                bSuccess = m_pMergeResultWindow->saveDocument(m_pMergeResultWindowTitle->getFileName(), m_pMergeResultWindowTitle->getEncoding(), m_pMergeResultWindowTitle->getLineEndStyle());
-                if(bSuccess) ::exit(0);
-            }
-        }
+        showMainWindow();
     }
+
     m_bAutoMode = false;
 
     if(statusBar() != nullptr)
@@ -656,7 +679,7 @@ void KDiff3App::initActions(KActionCollection* ac)
     mGoNextUnsolvedConflict = GuiUtils::createAction<QAction>(i18n("Go to Next Unsolved Conflict"), QIcon(QPixmap(nextunsolved)), i18n("Next\nUnsolved"), QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_PageDown), this, &KDiff3App::slotGoNextUnsolvedConflict, ac, "go_next_unsolved_conflict");
     mGoNextUnsolvedConflict->setToolTip(mGoNextUnsolvedConflict->text() + includeWhitespace);
     mGotoLine = GuiUtils::createAction<QAction>(i18nc("Title for menu item", "Go to Line"), QIcon(QPixmap(gotoline)), i18nc("Text used for toolbar button.", "Go\nLine"), QKeySequence(Qt::CTRL + Qt::Key_G), this, &KDiff3App::slotGoToLine, ac, "go_to_line");
-    mGoNextUnsolvedConflict->setToolTip(mGoNextUnsolvedConflict->text() + i18n(".\n Goto specified line."));
+    mGotoLine->setToolTip(mGotoLine->text() + i18nc("Additional text intooltip", ".\n Goto specified line."));
     chooseA = GuiUtils::createAction<KToggleAction>(i18nc("Title for menu item", "Select Line(s) From A"), QIcon(QPixmap(iconA)), i18nc("Text used for select A toolbar button.", "Choose\nA"), QKeySequence(Qt::CTRL + Qt::Key_1), this, &KDiff3App::slotChooseA, ac, "merge_choose_a");
     chooseB = GuiUtils::createAction<KToggleAction>(i18nc("Title for menu item", "Select Line(s) From B"), QIcon(QPixmap(iconB)), i18nc("Text used for select B when toolbar button.", "Choose\nB"), QKeySequence(Qt::CTRL + Qt::Key_2), this, &KDiff3App::slotChooseB, ac, "merge_choose_b");
     chooseC = GuiUtils::createAction<KToggleAction>(i18nc("Title for menu item", "Select Line(s) From C"), QIcon(QPixmap(iconC)), i18nc("Text used for select C toolbar button.", "Choose\nC"), QKeySequence(Qt::CTRL + Qt::Key_3), this, &KDiff3App::slotChooseC, ac, "merge_choose_c");
